@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 13177 2021-08-04 01:21:35Z Mint $
+# $Id: Backends.py 13215 2021-08-11 03:07:27Z Tiffany $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,16 +11,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Mint $
-# $Date: 2021-08-04 09:21:35 +0800 (週三, 04 八月 2021) $
-# $Revision: 13177 $
+# $Author: Tiffany $
+# $Date: 2021-08-11 11:07:27 +0800 (週三, 11 八月 2021) $
+# $Revision: 13215 $
 
 import re
-import os
-import sys
 import json
 import requests
-import django
     
 from passlib.apache import HtpasswdFile
 
@@ -35,7 +32,7 @@ DEFAULT_TRAC_AUTH_PASSWORD = getattr(settings, 'DEFAULT_TRAC_AUTH_PASSWORD', 'ei
 SET_TRAC_LOGIN_AS_STAFF = getattr(settings, "SET_TRAC_LOGIN_AS_STAFF", False)
 SET_TRAC_LOGIN_AS_SUPERUSER = getattr(settings, "SET_TRAC_LOGIN_AS_SUPERUSER", False)
 
-USER_DATA_PATTERN = "#\s+?(\w+):\s+?(\{.+\}?)"
+USER_DATA_PATTERN = r"#\s+?(\w+):\s+?(\{.+\}?)"
   
 class TracBackend(ModelBackend):
 
@@ -46,16 +43,17 @@ class TracBackend(ModelBackend):
         prog = re.compile(USER_DATA_PATTERN)
         data = {g[0]: json.loads(g[1]) for g in prog.findall(content)}
         ht = HtpasswdFile.from_string(content)
-        if not data.get(username, {}).get("email"):
-            raise PermissionDenied("No email in htfile for %s" % username)
-        else:
-            email = data.get(username, {}).get("email")
-        if ht.check_password(username, password):
-            return (True, email)
-
+        user = data.get(username)
+        if user:
+            if not user.get("email"):
+                raise PermissionDenied("No email in htfile for %s" % username)
+            else:
+                email = user.get("email")
+            if ht.check_password(username, password):
+                return (True, email)
         return (False, None)
 
-    def authenticate(self, request, username=None, password=None):
+    def authenticate(self, request, username=None, password=None, **kwargs):
         valid, email = self.check(username, password)
         if valid:
             try:
